Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(589)

Unified Diff: content/browser/child_process_launcher.h

Issue 11316261: Linux: inform the Zygote when it's waiting on a dead process (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address Adam's remarks. Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/browser_child_process_host_impl.cc ('k') | content/browser/child_process_launcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/child_process_launcher.h
diff --git a/content/browser/child_process_launcher.h b/content/browser/child_process_launcher.h
index e28419cec246769be2201ba7ce75132556a44fc6..9ee3d41b45be663dd183fe6a58a450a66d699870 100644
--- a/content/browser/child_process_launcher.h
+++ b/content/browser/child_process_launcher.h
@@ -53,11 +53,14 @@ class CONTENT_EXPORT ChildProcessLauncher {
// Getter for the process handle. Only call after the process has started.
base::ProcessHandle GetHandle();
- // Call this when the child process exits to know what happened to
- // it. |exit_code| is the exit code of the process if it exited
- // (e.g. status from waitpid if on posix, from GetExitCodeProcess on
- // Windows). |exit_code| may be NULL.
- base::TerminationStatus GetChildTerminationStatus(int* exit_code);
+ // Call this when the child process exits to know what happened to it.
+ // |known_dead| can be true if we already know the process is dead as it can
+ // help the implemention figure the proper TerminationStatus.
+ // |exit_code| is the exit code of the process if it exited (e.g. status from
+ // waitpid if on posix, from GetExitCodeProcess on Windows). |exit_code| may
+ // be NULL.
+ base::TerminationStatus GetChildTerminationStatus(bool known_dead,
+ int* exit_code);
// Changes whether the process runs in the background or not. Only call
// this after the process has started.
« no previous file with comments | « content/browser/browser_child_process_host_impl.cc ('k') | content/browser/child_process_launcher.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698